# twinstop
Twinstop identifies selenoproteins in close related transcriptomes

# Installation
conda install -c conda-forge -c bioconda -c mmariotti    twinstop

# Usage
Run:

  twinstop -h


# Authors
Sergio Sanchez Moragues and Marco Mariotti
